@@ -4,18 +4,10 @@ use Imager;
 use vars qw($VERSION @ISA);
 
 BEGIN {
-  $VERSION = "0.78";
+  $VERSION = "0.84";
 
-  eval {
-    require XSLoader;
-    XSLoader::load('Imager::File::GIF', $VERSION);
-    1;
-  } or do {
-print STDERR "Falling back to DynaLoader ($@)\n";
-    require DynaLoader;
-    push @ISA, 'DynaLoader';
-    bootstrap Imager::File::GIF $VERSION;
-  };
+  require XSLoader;
+  XSLoader::load('Imager::File::GIF', $VERSION);
 }
 
 Imager->register_reader
@@ -121,7 +113,7 @@ Imager's GIF support is documented in L<Imager::Files>.
 
 =head1 AUTHOR
 
-Tony Cook <tony@imager.perl.org>
+Tony Cook <tonyc@cpan.org>
 
 =head1 SEE ALSO
 
